@@ -4,6 +4,7 @@ from setux.core.distro import Distro
 class Fedora(Distro):
     Package = 'dnf'
     Service = 'SystemD'
+    pip_cmd = 'pip3'
 
     @classmethod
     def release_name(cls, infos):
@@ -18,4 +19,4 @@ class fedora_32(Fedora): pass
 
 class fedora_34(Fedora): pass
 
-
+class fedora_35(Fedora): pass
