@@ -3,7 +3,14 @@ from setux.core.mapping import Packages
 
 class Fedora(Packages):
     pkg = dict(
-        netcat = 'nmap-ncat',
+        setuptools = 'python3-setuptools',
+        pip        = 'python3-pip',
+        vim        = 'vim-enhanced',
+        gvim       = 'vim-X11',
+        shellcheck = 'ShellCheck',
+	sshfs      = 'fuse-sshfs',
+        netcat     = 'nmap-ncat',
+        ruby_dev   = 'ruby-devel',
     )
 
 
@@ -16,14 +23,6 @@ class Arch(Packages):
     )
 
 
-class Fedora(Packages):
-    pkg = dict(
-        setuptools = 'python3-setuptools',
-        pip        = 'python3-pip',
-        netcat     = 'nmap-ncat',
-    )
-
-
 class Artix(Packages):
     pkg = dict(
         setuptools = 'python-setuptools',
